Documentation
¶
Overview ¶
Package driver includes the interfaces required to implement a blobstore driver.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
ErrMetadataNotHandled = errors.New("this driver does not handle metadata")
)
Functions ¶
Types ¶
type Iterable ¶
Iterable is the interface implemented by drivers which can iterate over the files stored in them.
type Server ¶
type Server interface {
// Serve serves the file directly from the driver to the given
// http.ResponseWriter. If this function returns (false, nil)
// the blobstore will request the file to the driver and serve
// it by copying its contents to w. Any non nil error return
// will cause the blobstore to return an error to the caller.
Serve(w http.ResponseWriter, id string, rng Range) (bool, error)
}
Directories
¶
| Path | Synopsis |
|---|---|
|
Package file implements the file driver for the blobstore.
|
Package file implements the file driver for the blobstore. |
|
Package gcs provides a Google Cloud Storage driver for the Blobstore.
|
Package gcs provides a Google Cloud Storage driver for the Blobstore. |
|
Package gridfs implements a GridFS driver for the blobstore.
|
Package gridfs implements a GridFS driver for the blobstore. |
|
Package leveldb implements the levelb driver for the blobstore.
|
Package leveldb implements the levelb driver for the blobstore. |
|
Package s3 implements an s3 driver for the blobstore.
|
Package s3 implements an s3 driver for the blobstore. |
Click to show internal directories.
Click to hide internal directories.